@@ -1,20 +1,15 @@
 package Devel::Git::MultiBisect::AllCommits;
-use strict;
-use warnings;
 use v5.14.0;
+use warnings;
 use parent( qw| Devel::Git::MultiBisect | );
 use Devel::Git::MultiBisect::Opts qw( process_options );
-use Devel::Git::MultiBisect::Auxiliary qw(
-    clean_outputfile
-    hexdigest_one_file
-    validate_list_sequence
-);
 use Carp;
 use Cwd;
 use File::Temp;
 use List::Util qw(first sum);
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
+$VERSION = eval $VERSION;
 
 =head1 NAME
 
