@@ -1,14 +1,13 @@
 package Devel::Git::MultiBisect::Auxiliary;
-use strict;
-use warnings;
 use v5.14.0;
-our $VERSION = '0.16';
+use warnings;
+our $VERSION = '0.17';
+$VERSION = eval $VERSION;
 use base qw( Exporter );
 our @EXPORT_OK = qw(
     clean_outputfile
     hexdigest_one_file
     validate_list_sequence
-    get_current_branch
 );
 use Carp;
 use Digest::MD5;
@@ -298,15 +297,6 @@ sub validate_list_sequence {
     return [$status];
 }
 
-sub get_current_branch {
-    my @branches = qx{git branch};
-    chomp(@branches);
-    my ($cb, $current_branch);
-    $cb = first { m/^\*\s+?/ } @branches;
-    ($current_branch) = $cb =~ m{^\*\s+?(.*)};
-    return $current_branch;
-}
-
 1;
 
 
