@@ -1,19 +1,17 @@
 package Devel::Git::MultiBisect::BuildTransitions;
-use strict;
-use warnings;
 use v5.14.0;
+use warnings;
 use parent ( qw| Devel::Git::MultiBisect | );
 use Devel::Git::MultiBisect::Auxiliary qw(
     hexdigest_one_file
     validate_list_sequence
 );
 use Carp;
-use Cwd;
 use File::Spec;
 use File::Temp qw( tempdir );
-use Data::Dump qw(dd pp);
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
+$VERSION = eval $VERSION;
 
 =head1 NAME
 
@@ -27,7 +25,7 @@ Devel::Git::MultiBisect::BuildTransitions - Gather build-time output where it ch
 
     $commit_range = $self->get_commits_range();
 
-    $self->multisect_builds();
+    $self->multisect_builds( { probe => 'error' } );
 
     $multisected_outputs = $self->get_multisected_outputs();
 
@@ -36,14 +34,61 @@ Devel::Git::MultiBisect::BuildTransitions - Gather build-time output where it ch
 
 =head1 DESCRIPTION
 
-When the number of commits in the specified range is large and you only need
-the build-time output at those commits where the output materially changed, you can
-use this package, F<Devel::Git::MultiBisect::BuildTransitions>.
+Whereas F<Devel::Git::MultiBisect::Transitions> is concerned with B<test-time>
+failures, F<Devel::Git::MultiBisect::BuildTransitions> is concerned with
+B<build-time> phenomena:  exceptions and warnings.  We can identify three such
+cases:
+
+=over 4
+
+=item * Build-time failures
+
+While running your C-compiler over C source code via F<make>, an exception may
+be thrown which causes the build to fail.  Over a large number of commits,
+different exceptions may be thrown at various commits.  Identify those
+commits.
+
+=item * Build-time C-level warnings
+
+Your C-compiler may identify sub-optimal C source code and emit warnings.
+Over a large number of commits, different warnings may be thrown at various
+commits.  Identify the commits where the warnings changed.
+
+=item * Build-time non-C-level warnings
+
+At build time F<make> is not limited to running a C compiler; it may also
+execute statements in Perl, shell or other languages.  Those statements may
+themselves generate warnings.  Identify the commits where the F<STDERR> output
+from F<make> changes.
+
+=back
+
+These three cases are distinguished by the arguments passed to the
+C<multisect_builds()> method described below.
 
 =head1 METHODS
 
 =head2 C<new()>
 
+=over 4
+
+=item * Purpose
+
+Constructor.
+
+=item * Arguments
+
+    $self = Devel::Git::MultiBisect::BuildTransitions->new(\%params);
+
+Reference to a hash, typically the return value of
+C<Devel::Git::MultiBisect::Opts::process_options()>.
+
+=item * Return Value
+
+Object of Devel::Git::MultiBisect child class.
+
+=back
+
 =cut
 
 sub new {
@@ -64,25 +109,32 @@ sub new {
 =item * Purpose
 
 With a given set of configuration options and a specified range of F<git>
-commits, identify the point where the "build command" -- typically, F<make>
--- first threw exceptions and then all subsequent commits where the build-time
-exceptions materially changed.  A "material change" would be either a
-correction of all exceptions or a set of different build-time exceptions from
-those first observed.  Store the test output at those transition points for
-human inspection.
+commits, identify the points where the output of the "build command" --
+typically, F<make> -- materially changed.
+
+A B<material change> would be either (a) the emergence or correction of
+C-level exceptions; (b) the emergence or correction of C-level warnings; (c)
+the emergence or correction of F<STDERR> output emitted during F<make> by
+Perl, shell or other non-C code.
+
+These three cases are distinguished by the arguments passed to this method.
 
 =item * Arguments
 
-    $self->multisect_builds();
+    $self->multisect_builds();      # defaults to { probe => 'error' }
 
     $self->multisect_builds({ probe => 'error' });
 
     $self->multisect_builds({ probe => 'warning' });
 
+    $self->multisect_builds({ probe => 'stderr' });
+
 Optionally takes one hash reference.  At present that hashref may contain only
-one element whose key is C<probe> and whose possible values are C<error> or
-C<warning>.  Defaults to C<error>.  Select between those values depending on
-whether you are probing for changes in errors or changes in warnings.
+one element whose key is C<probe> and whose possible values are C<error>,
+C<warning>, or C<stderr>.  Defaults to C<error>.  Select among these values
+depending on whether you are probing for changes in errors generated by the
+C-compiler, changes in warnings generated by the C-compiler, or all text
+output to C<STDERR> during F<make>.
 
 =item * Return Value
 
@@ -96,12 +148,14 @@ As C<multisect_builds()> runs it does two kinds of things:
 
 =item *
 
-It stores results data within the object which you can subsequently access through method calls.
+It stores results data within the object which you can subsequently access
+through method calls.
 
 =item *
 
 It captures error messages from each commit run and writes them to a file on
-disk for later human inspection.
+disk for later human inspection.  (If you have selected C<probe =E<gt> 'stderr'>,
+all content directed to F<STDERR> is written to that file.)
 
 =back
 
@@ -112,6 +166,17 @@ disk for later human inspection.
 sub multisect_builds {
     my ($self, $args) = @_;
 
+    # Methods called within multisect_builds:
+    # _prepare_for_multisection
+    #       get_commits_range
+    #       run_build_on_one_commit
+    #           _configure_one_commit
+    #           _build_one_commit
+    #           _filter_build_log
+    # _run_one_commit_and_assign
+    # _bisection_decision
+    # _evaluate_status_of_build_runs
+
     if (defined $args) {
         croak "Argument passed to multisect_builds() must be hashref"
             unless ref($args) eq 'HASH';
@@ -120,7 +185,7 @@ sub multisect_builds {
             croak "Invalid key '$k' in hashref passed to multisect_builds()"
                 unless $good_keys{$k};
         }
-        my %good_values = map {$_ => 1} (qw| error warning |);
+        my %good_values = map {$_ => 1} (qw| error warning stderr |);
         for my $v (values %{$args}) {
             croak "Invalid value '$v' in 'probe' element in hashref passed to multisect_builds()"
                 unless $good_values{$v};
@@ -138,59 +203,55 @@ sub multisect_builds {
     my $start_time = time();
     my $all_outputs = $self->_prepare_for_multisection();
 
-=pod
-
-At this point, C<$all_outputs> is an array ref with one
-element per commit in the commit range.  If a commit has been visited, the
-element is a hash ref with 4 key-value pairs like the ones below.  If the
-commit has not yet been visited, the element is C<undef>.
-
-    [
-      {
-        commit => "7c9c5138c6a704d1caf5908650193f777b81ad23",
-        commit_short => "7c9c513",
-        file => "/home/jkeenan/learn/perl/multisect/7c9c513.make.errors.rpt.txt",
-        md5_hex => "d41d8cd98f00b204e9800998ecf8427e",
-      },
-      undef,
-      undef,
-    ...
-      undef,
-      {
-        commit => "8f6628e3029399ac1e48dfcb59c3cd30e5127c3e",
-        commit_short => "8f6628e",
-        file => "/home/jkeenan/learn/perl/multisect/8f6628e.make.errors.rpt.txt",
-        md5_hex => "fdce7ff2f07a0a8cd64005857f4060d4",
-      },
-    ]
-
-Unlike F<Devel::Git::MultiBisect::Transitions> -- where we could have been
-testing multiple test files on each commit -- here we're only concerned with
-recording the presence or absence of build-time errors.  Hence, we only need
-an array of hash refs rather than an array of arrays of hash refs.
-
-The multisection process will entail running C<run_build_on_one_commit()> over
-each commit selected by the multisection algorithm.  Each run will insert a hash
-ref with the 4 KVPs into C<@{$self-E<gt>{all_outputs}}>.  At the end of the
-multisection process those elements which we did not need to visit will still be
-C<undef>.  We will then analyze the defined elements to identify the
-transitional commits.
-
-The objective of multisection is to identify the git commits at which the
-build output -- as reflected in a file on disk holding a list of normalized
-errors -- materially changed.  We are using an md5_hex value for that error
-file as a presumably valid unique identifier for that file's content.  A
-transition point is a commit at which the output file's md5_hex differs from
-that of the immediately preceding commit.  So, to identify the first
-transition point, we need to locate the commit at which the md5_hex changed
-from that found in the very first commit in the designated commit range.  Once
-we've identified the first transition point, we'll look for the second
-transition point, i.e., that where the md5_hex changed from that observed at
-the first transition point.  We'll continue that process until we get to a
-transition point where the md5_hex is identical to that of the very last
-commit in the commit range.
-
-=cut
+# At this point, C<$all_outputs> is an array ref with one
+# element per commit in the commit range.  If a commit has been visited, the
+# element is a hash ref with 4 key-value pairs like the ones below.  If the
+# commit has not yet been visited, the element is C<undef>.
+#
+#     [
+#       {
+#         commit => "7c9c5138c6a704d1caf5908650193f777b81ad23",
+#         commit_short => "7c9c513",
+#         file => "/home/jkeenan/learn/perl/multisect/7c9c513.make.errors.rpt.txt",
+#         md5_hex => "d41d8cd98f00b204e9800998ecf8427e",
+#       },
+#       undef,
+#       undef,
+#     ...
+#       undef,
+#       {
+#         commit => "8f6628e3029399ac1e48dfcb59c3cd30e5127c3e",
+#         commit_short => "8f6628e",
+#         file => "/home/jkeenan/learn/perl/multisect/8f6628e.make.errors.rpt.txt",
+#         md5_hex => "fdce7ff2f07a0a8cd64005857f4060d4",
+#       },
+#     ]
+#
+# Unlike F<Devel::Git::MultiBisect::Transitions> -- where we could have been
+# testing multiple test files on each commit -- here we're only concerned with
+# recording the presence or absence of build-time errors.  Hence, we only need
+# an array of hash refs rather than an array of arrays of hash refs.
+#
+# The multisection process will entail running C<run_build_on_one_commit()> over
+# each commit selected by the multisection algorithm.  Each run will insert a hash
+# ref with the 4 KVPs into C<@{$self-E<gt>{all_outputs}}>.  At the end of the
+# multisection process those elements which we did not need to visit will still be
+# C<undef>.  We will then analyze the defined elements to identify the
+# transitional commits.
+#
+# B<The objective of multisection is to identify the git commits at which the
+# build output> -- as reflected in a file on disk holding a list of normalized
+# errors, normalized warnings or C<STDERR> -- B<materially changed.>  We are using
+# an md5_hex value for that error file as a presumably valid unique identifier
+# for that file's content.  A transition point is a commit at which the output
+# file's md5_hex differs from that of the immediately preceding commit.  So, to
+# identify the first transition point, we need to locate the commit at which the
+# md5_hex changed from that found in the very first commit in the designated
+# commit range.  Once we've identified the first transition point, we'll look
+# for the second transition point, i.e., that where the md5_hex changed from
+# that observed at the first transition point.  We'll continue that process
+# until we get to a transition point where the md5_hex is identical to that of
+# the very last commit in the commit range.
 
     my ($min_idx, $max_idx)     = (0, $#{$self->{commits}});
     my $this_target_status      = 0;
@@ -238,14 +299,14 @@ commit in the commit range.
 
     my $end_time = time();
     my %timings = (
-	    elapsed	=> $end_time - $start_time,
-        runs => scalar( grep {defined $_} @{$self->{all_outputs}} ),
+        elapsed => $end_time - $start_time,
+        runs    => scalar( grep {defined $_} @{$self->{all_outputs}} ),
     );
     $timings{mean} = sprintf("%.02f" => $timings{elapsed} / $timings{runs});
     if ($self->{verbose}) {
         say "Ran $timings{runs} runs; elapsed: $timings{elapsed} sec; mean: $timings{mean} sec";
     }
-    $self->{timings}	  = \%timings;
+    $self->{timings} = \%timings;
 
     return 1;
 }
@@ -293,17 +354,44 @@ sub run_build_on_one_commit {
 sub _build_one_commit {
     my ($self, $commit) = @_;
     my $short_sha = substr($commit,0,$self->{short});
-    my $build_log = File::Spec->catfile(
-        $self->{outputdir},
-        join('.' => (
-            $short_sha,
-            'make',
-            'output',
-            'txt'
-        )),
-    );
     my $command_raw = $self->{make_command};
-    my $cmd = qq|$command_raw > $build_log 2>&1|;
+
+    # If probe => error or probe => warning, we are capturing the entire
+    # (2>&1) output of 'make' in a file and then filtering that file (in
+    # _filter_build_log() for either C-level exceptions or C-level warnings.
+    # Hence, that file's name should end in 'make.output.txt'.
+    #
+    # If, however, probe => stderr, we are directly filtering the output of
+    # 'make' for STDERR and saving that in a file for subsequent
+    # commit-by-commit comparison of the STDERR output.  Hence, the file for
+    # each commit should end in 'make.stderr.txt'.
+
+    my ($build_log, $cmd);
+    if ($self->{probe} eq 'stderr') {
+        $build_log = File::Spec->catfile(
+            $self->{outputdir},
+            join('.' => (
+                $short_sha,
+                'make',
+                'stderr',
+                'txt'
+            )),
+        );
+        $cmd = qq|$command_raw 2>$build_log|;
+    }
+    else {
+        $build_log = File::Spec->catfile(
+            $self->{outputdir},
+            join('.' => (
+                $short_sha,
+                'make',
+                'output',
+                'txt'
+            )),
+        );
+        $cmd = qq|$command_raw >$build_log 2>&1|;
+    }
+    say "Actual 'make' command: $cmd" if $self->{verbose};
     my $rv = system($cmd);
     my $filtered_probes_file = $self->_filter_build_log($build_log, $short_sha);
     say "Created $filtered_probes_file" if $self->{verbose};
@@ -317,7 +405,6 @@ sub _build_one_commit {
 
 sub _filter_build_log {
     my ($self, $buildlog, $short_sha) = @_;
-    say "short_sha: $short_sha";
     my $tdir = tempdir( CLEANUP => 1 );
 
     if ($self->{probe} eq 'error') {
@@ -325,7 +412,6 @@ sub _filter_build_log {
         my $ackpattern = q|-A2 '^[^:]+:\d+:\d+:\s+error:'|;
         my @raw_acklines = grep { ! m/^--\n/ } `ack $ackpattern $buildlog`;
         chomp(@raw_acklines);
-        #pp(\@raw_acklines);
         croak "Got incorrect count of lines from ack; should be divisible by 3"
             unless scalar(@raw_acklines) % 3 == 0;
 
@@ -340,7 +426,7 @@ sub _filter_build_log {
         }
 
         my $error_report_file =
-            File::Spec->catfile($self->{workdir}, "$short_sha.make.errors.rpt.txt");
+            File::Spec->catfile($self->{outputdir}, "$short_sha.make.errors.rpt.txt");
         say "rpt: $error_report_file";
         open my $OUT, '>', $error_report_file
             or croak "Unable to open $error_report_file for writing";
@@ -354,7 +440,7 @@ sub _filter_build_log {
         close $OUT or croak "Unable to close $error_report_file after writing";
         return $error_report_file;
     }
-    else {
+    elsif ($self->{probe} eq 'warning') {
         my $ackpattern = qr/^
             ([^:]+):
             (\d+):
@@ -375,14 +461,19 @@ sub _filter_build_log {
         close $IN or croak "Unable to close $buildlog after reading";
 
         my $warning_report_file =
-            File::Spec->catfile($self->{workdir}, "$short_sha.make.warnings.rpt.txt");
-        say "rpt: $warning_report_file";
+            File::Spec->catfile($self->{outputdir}, "$short_sha.make.warnings.rpt.txt");
         open my $OUT, '>', $warning_report_file
             or croak "Unable to open $warning_report_file for writing";
         say $OUT $_ for @refined_warnings;
         close $OUT or croak "Unable to close $warning_report_file after writing";
         return $warning_report_file;
     }
+    else {
+        # $self->{probe} eq 'stderr'
+        # With this option, we simply record all STDERR from 'make' in the
+        # build log and return it.
+        return $buildlog;
+    }
 }
 
 sub _evaluate_status_of_build_runs {
